# pyAirtable (formerly airtable-python-wrapper)

![Build](https://github.com/gtalarico/airtable-python-wrapper/actions/workflows/test.yml/badge.svg)
[![PyPI - 0.x](https://img.shields.io/pypi/dm/airtable-python-wrapper.svg?label=pypi%20downloads)](https://pypi.org/project/airtable-python-wrapper/)
[![PyPI - 1.x](https://img.shields.io/pypi/dm/pyairtable.svg?label=pypi%20downloads)](https://pypi.org/project/pyairtable/)
[![codecov](https://codecov.io/gh/gtalarico/pyairtable/branch/main/graph/badge.svg?token=askmZgmMoV)](https://codecov.io/gh/gtalarico/pyairtable)
[![Documentation Status](https://readthedocs.org/projects/pyairtable/badge/?version=latest)](http://pyairtable.readthedocs.io/en/latest/?badge=latest)

Python Client for the Airtable Api

## Installing

```
pip install pyairtable
```

## Documentation

Checkout the docs on [pyairtable.readthedocs.io](http://pyairtable.readthedocs.io/)


### Looking for **airtable-python-wrapper**?

airtable-python-wrapper is now **pyAirtable**.
For the previous version go to https://github.com/gtalarico/airtable-python-wrapper/tree/airtable-python-wrapper
